Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(590)

Unified Diff: chrome/browser/instant/instant_page.h

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Don't run test on Mac & Linux Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/instant/instant_extended_browsertest.cc ('k') | chrome/browser/instant/instant_page.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/instant/instant_page.h
diff --git a/chrome/browser/instant/instant_page.h b/chrome/browser/instant/instant_page.h
index f0167c2e2c907f9cfe4d213e8a2992d03560b419..1260beb1e5307c57410ab9276fc44db92ff62239 100644
--- a/chrome/browser/instant/instant_page.h
+++ b/chrome/browser/instant/instant_page.h
@@ -131,10 +131,9 @@ class InstantPage : public content::WebContentsObserver {
// by the omnibox dropdown.
void SetPopupBounds(const gfx::Rect& bounds);
- // Tells the page the start and end margins of the omnibox (in screen
- // coordinates). This is used by the page to align text or assets properly
- // with the omnibox.
- void SetMarginSize(int start, int end);
+ // Tells the page the bounds of the omnibox (in screen coordinates). This is
+ // used by the page to align text or assets properly with the omnibox.
+ void SetOmniboxBounds(const gfx::Rect& bounds);
// Tells the page about the font information.
void InitializeFonts();
« no previous file with comments | « chrome/browser/instant/instant_extended_browsertest.cc ('k') | chrome/browser/instant/instant_page.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698